package intro2java.download;

import java.net.*;
import java.io.*;

/**
 * This is a helper class that provides facilities for
 * fetching a file from the Internet and storing it someone
 * locally.
 *
 * @author Leigh Dodds
 */
public class DownloadManager
{


    /**
     * Requests the download of a given file from the URL provided
     * as a string
     *
     * @see #downloadFile(URL)
     */
    public long downloadFile(String url) throws IOException
    {
        return downloadFile( new URL(url) );
    }

    /**
     * Requests the download of a given file from the provided
     * URL.
     *
     * @param url the full url to the file to download
     * @return the number of bytes downloads
     */
    public long downloadFile(URL url) throws IOException
    {
        //create a new file in our local filestore
        //use the filename in the url
        File localFile = new File(System.getProperty("user.home"), makeFileName(url));
        System.out.println(localFile.getAbsolutePath());
        //open an input stream to this url
        InputStream inner = url.openStream();
        BufferedInputStream in = new BufferedInputStream(inner);

        //open an output stream to the local file
        FileOutputStream outer = new FileOutputStream(localFile);
        BufferedOutputStream out = new BufferedOutputStream(outer);

        //start counter
        long counter =0;

        //read the first byte...
        int aByte = in.read();

        //...and keep reading until there are no left
        while (aByte != -1)
        {
            //increment the counter
            counter++;
            //store the byte
            out.write(aByte);
            //read the next one
            aByte = in.read();
        }

        //close the streams
        in.close();
        out.close();

        return counter;
    }

    private String makeFileName(URL url)
    {
        String urlAsString = url.toString();

        int index = urlAsString.lastIndexOf("/");
        return urlAsString.substring(index);
    }
}