package intro2java.download;

import java.io.*;
import java.net.*;

/**
 * A simple command-line application to read a list of URLs from
 * a file, and then download each of them in turn to the users home
 * directory.
 *
 * @author Leigh Dodds
 */
public class FileFetcher
{

    private String _listOfFiles;
    private DownloadManager _manager;


    public FileFetcher(String listOfFiles)
    {
        _listOfFiles = listOfFiles;
        _manager = new DownloadManager();
    }

    public void downloadFiles() throws IOException
    {
        //create a file object
        File list = new File(_listOfFiles);

        //create a buffered reader to read lines from the file
        BufferedReader in = new BufferedReader( new FileReader(list) );

        //read the first line...
        String url = in.readLine();

        //..and keep reading until we reach the end
        while (url != null)
        {
            downloadFile(url);
            url = in.readLine();
        }

        //close the file
        in.close();
    }

    /**
     * A helper method. Catches exceptions from the download manager so
     * that errors in one file download, don't affect the others.
     */
    private void downloadFile(String url)
    {
        try
        {
            System.out.println("Downloading file: " + url);

            //delegate the hard work to the download manager object
            long bytes = _manager.downloadFile(url);

            System.out.println(bytes + " bytes downloaded successfully");

        } catch (MalformedURLException me)
        {
            System.out.println("Illegal URL " + url);
        } catch (IOException e)
        {
            System.out.println("Error downloading " + url);
        }
    }

    public static void main(String[] args)
    {
        //check we've got the required arguments
        if (args.length != 1)
        {
            System.out.println("Usage: java intro2java.download.FileFetcher listOfFiles.txt");
            System.exit(1);
        }

        String listOfFiles = args[0];

        FileFetcher fetcher = new FileFetcher(listOfFiles);

        try
        {
            fetcher.downloadFiles();
        } catch (IOException e)
        {
            System.out.println("Problem reading from file " + listOfFiles);
            e.printStackTrace();
        }
    }

}